import { memo } from 'react';
import { jsx, Fragment } from 'react/jsx-runtime';

function For({
  each,
  fallback,
  children
}) {
  if (each === undefined || each === null || each.length === 0) {
    return fallback != null ? fallback : null;
  }
  return each.map(children);
}

const TypedMemo = memo;

const ForMemo = TypedMemo(For);

function ForIf({
  each,
  when,
  fallback,
  children
}) {
  return jsx(For, {
    each: each == null ? void 0 : each.filter(when),
    fallback: fallback,
    children: children
  });
}

const ForIfMemo = TypedMemo(ForIf);

function Show({
  when,
  fallback,
  children
}) {
  if (when !== undefined && when !== null && when === true) {
    return children;
  }
  return fallback != null ? fallback : null;
}

function Hide({
  when,
  fallback,
  children
}) {
  return jsx(Show, {
    when: when === false || when === undefined || when === null,
    fallback: fallback,
    children: children
  });
}

function Switch({
  fallback,
  children
}) {
  const showFallback = () => {
    if (!Array.isArray(children)) {
      return children.props.when === undefined || children.props.when === null || !children.props.when;
    }
    return children.every(child => child.props.when === undefined || child.props.when === null || !child.props.when);
  };
  if (showFallback()) {
    return fallback != null ? fallback : null;
  }
  return jsx(Fragment, {
    children: children
  });
}
function Match({
  when,
  children
}) {
  return jsx(Show, {
    when: when,
    children: children
  });
}

export { For, ForIf, ForIfMemo, ForMemo, Hide, Match, Show, Switch };
//# sourceMappingURL=index.js.map
